@@ -341,11 +341,12 @@ build_popup_menu (EvSidebarLinks *sidebar)
 	GtkWidget *item;
 
 	menu = gtk_menu_new ();
-	item = gtk_label_new_with_mnemonic(_("Print…"));
+	item = gtk_menu_item_new_with_mnemonic(_("Print…"));
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 	g_signal_connect (item, "activate",
 			  G_CALLBACK (print_section_cb), sidebar);
+	gtk_menu_attach_to_widget (menu, sidebar->priv->tree_view, NULL);
 
 	return GTK_MENU (menu);
 }
@@ -518,7 +519,7 @@ row_collapsed_cb (GtkTreeView *tree_view,
 		if (ev_metadata_get_string (metadata, "index-collapse", &index_collapse)) {
 			/* If collapsed row is not in 'index_collapse' we add it. */
 			if (g_strstr_len (index_collapse, -1, path_token) == NULL) {
-				if (!strcmp (index_expand, ""))
+				if (!index_expand || !strcmp (index_expand, ""))
 					new_index = g_strconcat (index_collapse, path_token, NULL);
 				else
 					new_index = g_strconcat (index_collapse, path_token + 1, NULL);
